#!/bin/bash
# -*- coding: utf-8 -*-
# vim: tabstop=2 expandtab shiftwidth=2 softtabstop=2
# vim: set fileencoding=utf-8
exec 1> >(systemd-cat -p info -t lte-hotplug) 2>&1
#
source /scripts/basic_vars
source /scripts/basic_functions
source /root/admin-openrc.sh
#
set -o xtrace
set -o nounset
set -o pipefail
set -o errexit
#
echo "LTE hotplug -- $* --"
#

iface=$2
LTEIF_OFPORT=9


if [ "del" == "$1" ]; then
  /sbin/ifdown --verbose --ignore-errors --force --interfaces /etc/network/interfaces.d/ifcfg-$iface $iface || true
  /scripts/apply_networking.py -z $iface || true
  rm -rf /config/_lte_dongle_detect/$iface || true
  #bug 4540 - during initial homecalling, ignore old lease files, and prevent from invalid GW to be installed
  rm -f /var/lib/dhcp/dhclient.$iface.leases || true
  rm -rf /run/lock-$iface || true
  /sbin/ifdown br-${iface} || true
  /sbin/ip addr flush dev br-${iface} || true
  exit 0
fi
#
lte_enabled=$(sysrepocfg -X -x "/ucpe:config/interfaces:interface[name='${iface}']/enable -f json" | grep enable | cut -d' ' -f10 | grep true)
system_is_starting=$(systemctl status | head -n 2 | tail -n 1 | grep starting || true)
#
echo "LTE hotplug lte_enabled --${lte_enabled}-- system_is_starting --${system_is_starting}--"
#
if [ -n "${lte_enabled}" ] && [ -z "${system_is_starting}" ]; then
  echo "status: $(ifconfig ${iface})"
  ovs_status=$(systemctl is-enabled ovs-config.service || true)
  if [[ "${ovs_status}" == "enabled" || "${ovs_status}" == "static" ]]; then
    # OVS
    ovs-vsctl br-exists br-${iface}
    if [ 0 == $? ]; then
      /usr/bin/ovs-vsctl add-port br-${iface} ${iface} || true
      /usr/bin/ovs-vsctl -- set Interface ${iface} ofport_request=${LTEIF_OFPORT} || true
      if [ -f /sys/class/net/${iface}/address ] && [ -s /sys/class/net/${iface}/address ]; then
        mac=$(cat /sys/class/net/${iface}/address)
        if [ ! -z ${mac} ]; then 
          /usr/bin/ovs-vsctl set bridge br-${iface} other-config:hwaddr=${mac}
        fi
      fi
      /sbin/ifdown br-${iface} || true
      /sbin/ip addr flush dev br-${iface} || true
      rm -f /var/lib/dhcp/dhclient.br-$iface.leases
      touch /config/_reboot/ifup/br-${iface}  || true
    else
      /scripts/apply_networking.py -n ${iface} -o yes -b dhcp
    fi
  else
    # VPP
    /sbin/ifdown br-${iface}
    /sbin/ip addr flush dev br-${iface} || true
    rm -f /var/lib/dhcp/dhclient.br-$iface.leases
    if [[ "$iface" == "lte1" || "$iface" == "lte2" ]]; then
           /scripts/vpp_lte_reinit.py $iface || true
    fi
    touch /config/_reboot/ifup/br-${iface} || true
  fi
  #bug 4540 - during initial homecalling, ignore old lease files, and prevent from invalid GW to be installed
  echo "Wait until $iface is fully initilized"
  echo "Try bringing $iface up.."
  /sbin/ifup --verbose --ignore-errors --force --interfaces /etc/network/interfaces.d/ifcfg-$iface $iface
fi
#
exit 0
